# Disallow `process.exit()`

<!-- Do not manually modify RULE_NOTICE part. Run: `npm run generate-rule-notices` -->
<!-- RULE_NOTICE -->
✅ *This rule is part of the [recommended](https://github.com/sindresorhus/eslint-plugin-unicorn#recommended-config) config.*
<!-- /RULE_NOTICE -->

This rule is an extension to ESLint's [`no-process-exit` rule](https://eslint.org/docs/rules/no-process-exit), that allows `process.exit()` to be called in files that start with a [hashbang](https://en.wikipedia.org/wiki/Shebang_(Unix)) → `#!/usr/bin/env node`. It also allows `process.exit()` to be called in `process.on('<event>', func)` event handlers and in files that imports `worker_threads`.

## Fail

```js
process.exit(0);
```

## Pass

```js
#!/usr/bin/env node
process.exit(0);
```

```js
process.on('SIGINT', () => {
    console.log('Got SIGINT');
    process.exit(1);
});
```

```js
import workerThreads from 'worker_threads';

try {
	// Do something…
	process.exit(0);
} catch (_) {
	process.exit(1);
}
```
